pub struct SeccompOpts { /* private fields */ }Expand description
Options for apply_seccomp.
Implementations
Sourceimpl SeccompOpts
impl SeccompOpts
Sourcepub fn network_fallback() -> Self
pub fn network_fallback() -> Self
Apply Landlock filesystem/process sandboxing and use seccomp as the network fallback when Landlock lacks TCP filtering support.
Sourcepub fn external_tcp() -> Self
pub fn external_tcp() -> Self
Apply Landlock filesystem/process sandboxing, but skip nono-managed TCP network enforcement because the deployment enforces egress externally.